.. image:: https://readthedocs.org/projects/ymmsl-python/badge/?version=master
    :target: https://ymmsl-python.readthedocs.io/en/latest/?badge=master
    :alt: Documentation Build Status

.. image:: https://api.travis-ci.org/multiscale/ymmsl-python.svg?branch=master
    :target: https://travis-ci.org/multiscale/ymmsl-python
    :alt: Build Status

.. image:: https://api.codacy.com/project/badge/Grade/77d0caaf9c44473caf02670df04f02b2
    :target: https://www.codacy.com/app/LourensVeen/ymmsl-python
    :alt: Codacy Grade

.. image:: https://api.codacy.com/project/badge/Coverage/77d0caaf9c44473caf02670df04f02b2
    :target: https://www.codacy.com/app/LourensVeen/ymmsl-python
    :alt: Code Coverage

.. image:: https://requires.io/github/multiscale/ymmsl-python/requirements.svg?branch=master
    :target: https://requires.io/github/multiscale/ymmsl-python/requirements/?branch=master
    :alt: Requirements Status

.. image:: https://zenodo.org/badge/153272345.svg
   :target: https://zenodo.org/badge/latestdoi/153272345

################################################################################
yMMSL Python bindings
################################################################################

Python bindings for the YAML version of the Multiscale Modeling and Simulation
Language.

This package provides a Python library for reading and writing yMMSL files.
These files describe multiscale models and/or parameter settings for
running such a model. This library is based on
`YAtiML <https://yatiml.rtd.io>`_, a Python library for making libraries for
YAML-based file formats like this one.

Documentation
*************

This is an ordinary Python library that can be installed via pip. It requires
Python 3.4 or higher. More information is available in the `online
documentation for ymmsl-python <https://ymmsl-python.readthedocs.io>`_.

Development
***********

This library is developed in `its public GitHub repository
<https://github.com/multiscale/ymmsl-python>`_. If you run into a problem or
something is unclear, please file an issue.

Legal
*****

ymmsl_python is Copyright 2019 Netherlands eScience Center and University of
Amsterdam. Licensed under the Apache 2.0 license.

